@@ -1,24 +1,24 @@
 from gym.envs.registration import register
 
 register(
-    id='Inventory-v0',
+    id='Inventory-v1',
     entry_point='cpagym.envs.grid_world:InventoryEnv',
 )
 
 register(
-    id='forex-v0',
+    id='forex-v1',
     entry_point='cpagym.envs.forex_env:ForexEnv',
 )
 
 register(
-    id='stocks-v0',
+    id='stocks-v1',
     entry_point='cpagym.envs.stocks_env:StocksEnv',
 )
 register(
-    id='trading-v0',
+    id='trading-v1',
     entry_point='cpagym.envs.trading_env:TradingEnv',
 )
 register(
-    id='AsymmetricInfo',
+    id='AsymmetricInfo-v1',
     entry_point='cpagym.envs.asymmetricInfo_env:AsymmetricInfoEnv',
 )
\ No newline at end of file
